@@ -1,7 +1,7 @@
 # yrfraction.R
 # fraction of the year for a date, includes leap year
-# type = 'monthly' or 'daily' (default)
-# April 2009
+# type = 'monthly', 'weekly' or 'daily' (default)
+# Jan 2014
 
 yrfraction<-function(date,type='daily'){
   if (type=='daily'){
@@ -12,6 +12,10 @@ yrfraction<-function(date,type='daily'){
     yrlength<-as.numeric(format(lastday,'%j'));
     yrfrac<-(day-1)/yrlength;
   }
+  if (type=='weekly'){
+    if (max(date)>53|min(date)<1){stop("Date variable for weekly data must be month integer (1 to 53)")} 
+    yrfrac<-(date-1)/(365.25/7);
+  }
   if (type=='monthly'){
     if (max(date)>12|min(date)<1){stop("Date variable for monthly data must be month integer (1 to 12)")} 
     yrfrac<-(date-1)/12;
